@@ -302,7 +302,7 @@ def split_dataset(
 
     if len(unique_groups) < nsplits:
         raise ValueError(
-            "The number of unique groups has to be greater " "than the number of partitions."
+            "The number of unique groups has to be greater than the number of partitions."
         )
     shuffle(unique_groups)
     partitions = []
@@ -887,6 +887,18 @@ def add_file_extension(fname: Union[str, Path], ext: str) -> str:
     raise ValueError(f"Passed extenstion {current_ext} expected {ext}")
 
 
+def get_size_from_cf_name(cf_name: str) -> int:
+    """Extract the size from a CF name."""
+    if not cf_name.startswith("c"):
+        raise ValueError(f"The name {cf_name} doesn't look like a CF name.")
+    # Regex for finding the first integer occurence.
+    res = re.search(r"\d+", cf_name)
+    if not res:
+        # No numbers were found in the string.
+        raise ValueError(f"No numbers present in name: {cf_name}")
+    return int(res.group())
+
+
 def sort_cf_names(cf_names: tIterable[str]) -> List[str]:
     """
     Return a sorted list of correlation function names. The names are
@@ -896,7 +908,7 @@ def sort_cf_names(cf_names: tIterable[str]) -> List[str]:
     2. Diameter
     3. Lexicographical order of the name itself
     """
-    sizes = [int(n[1]) for n in cf_names]
+    sizes = [get_size_from_cf_name(n) for n in cf_names]
     # Regular expression that extracts all digits after the occurence
     # of _d (e.g. c2_d0001_0_00 --> 0001)
     prog = re.compile("_d(\\d+)")
@@ -1244,3 +1256,46 @@ def get_repetition(prim: ase.Atoms, atoms: ase.Atoms) -> np.ndarray:
     P = atoms.get_cell() @ p_inv
 
     return np.rint(np.diag(P)).astype(int)
+
+
+def wrap_positions_3d(
+    positions: np.ndarray,
+    cell: np.ndarray,
+    center=(0.5, 0.5, 0.5),
+    cell_T_inv: np.ndarray = None,
+    eps: float = 1e-7,
+) -> np.ndarray:
+    """Similar to the ase.geometry.wrap_positions but this implementation assumes that the
+    cell is a fully 3-D periodic.
+    Assumes all directions are periodic! Also assumes the cell is correctly completed,
+    without any missing lattice vectors.
+
+    The inverse of the transposed cell is required, and can be provided as a pre-computed
+    quantity for reuse. This will be computed if not provided.
+
+    Args:
+        positions (np.ndarray): The positions to be wrapped.
+        cell (np.ndarray): Unit cell vectors of the atoms object.
+        center (tuple, optional): The positons in fractional coordinates that the new positions
+            will be nearest possible to. Defaults to (0.5, 0.5, 0.5).
+        cell_T_inv (np.ndarray, optional): A pre-computed inverse of the transposed cell.
+            Will be calculated, if it is not provided. Will not check if the provided
+            inverse is correct. Defaults to None.
+        eps (float, optional): Small number to prevent slightly negative coordinates from being
+            wrapped. Defaults to 1e-7.
+
+    Returns:
+        np.ndarray: The wrapped positions
+    """
+
+    shift = np.asarray(center) - 0.5 - eps
+
+    # If the cell_T_inv is not None, assume it was provided correctly.
+    if cell_T_inv is None:
+        cell_T_inv = np.linalg.inv(cell.T)
+
+    fractional = cell_T_inv.dot(positions.T).T - shift
+    fractional %= 1.0
+    fractional += shift
+
+    return np.dot(fractional, cell)
