@@ -1,16 +1,16 @@
 #ifndef BASIS_FUNCTION_H
 #define BASIS_FUNCTION_H
-#include "symbols_with_numbers.hpp"
+#include <iostream>
 #include <map>
 #include <vector>
-#include <iostream>
+
+#include "symbols_with_numbers.hpp"
 
 typedef std::map<std::string, double> dict_dbl_t;
 typedef std::vector<dict_dbl_t> bf_raw_t;
 
-class BasisFunction
-{
-public:
+class BasisFunction {
+   public:
     BasisFunction();
     BasisFunction(const bf_raw_t &raw_bfs, const Symbols &symb_with_num);
     BasisFunction(const BasisFunction &other);
@@ -21,12 +21,14 @@ public:
     double get(unsigned int dec_num, unsigned int symb_id) const;
 
     /** Return the size (number of basis functions) */
-    unsigned int size() const { return num_bfs; };
+    unsigned int size() const {
+        return num_bfs;
+    };
 
     /** Stream operator */
     friend std::ostream &operator<<(std::ostream &out, const BasisFunction &bf);
 
-private:
+   private:
     const Symbols *symb_ptr{nullptr};
     std::vector<double> bfs;
     unsigned int num_bfs{0};
